@@ -47,6 +47,7 @@ class Tibber:
         self._all_home_ids = []
         self._homes = {}
         self.sub_manager = None
+        self.user_agent = "pyTibber"
 
     async def close_connection(self):
         """Close the Tibber connection."""
@@ -89,12 +90,12 @@ class Tibber:
             if "pyTibber" not in user_agent:
                 post_args["headers"][
                     aiohttp.hdrs.USER_AGENT
-                ] = f"{user_agent} pyTibber/{__version__}"
+                ] = f"{user_agent} {self.user_agent}/{__version__}"
         except Exception:  # pylint: disable=broad-except
             pass
 
         try:
-            with async_timeout.timeout(self._timeout):
+            async with async_timeout.timeout(self._timeout):
                 resp = await self.websession.post(API_ENDPOINT, **post_args)
             if resp.status != 200:
                 _LOGGER.error("Error connecting to Tibber, resp code: %s", resp.status)
@@ -240,7 +241,6 @@ class TibberHome:
         self._current_price_info = {}
         self._price_info = {}
         self._level_info = {}
-        self.sub_manager = None
         self.info = {}
         self._subscription_id = None
         self._data = None
@@ -596,30 +596,28 @@ class TibberHome:
             """
             subscription{
               liveMeasurement(homeId:"%s"){
-                timestamp
-                power
-                powerProduction
-                accumulatedProduction
                 accumulatedConsumption
                 accumulatedCost
+                accumulatedProduction
+                accumulatedProductionLastHour
                 accumulatedReward
-                currency
-                minPower
                 averagePower
-                maxPower
-                voltagePhase1
-                voltagePhase2
-                voltagePhase3
+                currency
                 currentL1
                 currentL2
                 currentL3
                 lastMeterConsumption
                 lastMeterProduction
-                signalStrength
-                accumulatedConsumptionLastHour
-                accumulatedProductionLastHour
+                maxPower
+                minPower
+                power
                 powerFactor
+                powerProduction
                 powerReactive
+                signalStrength
+                voltagePhase1
+                voltagePhase2
+                voltagePhase3
             }
            }
         """
